@@ -6,6 +6,7 @@ import logging
 import os
 import re
 import sys
+from collections.abc import Mapping
 from dataclasses import dataclass
 from pathlib import Path
 from typing import TYPE_CHECKING, NamedTuple
@@ -13,8 +14,9 @@ from typing import TYPE_CHECKING, NamedTuple
 import black
 import jinja2
 from ansible.errors import AnsibleError, AnsibleFilterError, AnsibleParserError
-from ansible.parsing.yaml.objects import AnsibleUnicode
+from ansible_compat.config import ansible_version
 from jinja2.exceptions import TemplateSyntaxError
+from packaging.version import Version
 
 from ansiblelint.errors import RuleMatchTransformMeta
 from ansiblelint.file_utils import Lintable
@@ -22,6 +24,7 @@ from ansiblelint.rules import AnsibleLintRule, TransformMixin
 from ansiblelint.runner import get_matches
 from ansiblelint.skip_utils import get_rule_skips_from_line
 from ansiblelint.text import has_jinja
+from ansiblelint.types import AnsibleTemplateSyntaxError
 from ansiblelint.utils import (  # type: ignore[attr-defined]
     Templar,
     parse_yaml_from_file,
@@ -144,11 +147,15 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                     except AnsibleFilterError:
                         bypass = True
                     # ValueError RepresenterError
-                    except AnsibleError as exc:
+                    except (AnsibleError, ImportError) as exc:
                         bypass = False
-                        orig_exc = (
-                            exc.orig_exc if getattr(exc, "orig_exc", None) else exc
-                        )
+                        orig_exc = exc
+                        if (
+                            isinstance(exc, AnsibleError)
+                            and hasattr(exc, "orig_exc")
+                            and exc.orig_exc
+                        ):
+                            orig_exc = exc.orig_exc
                         orig_exc_message = getattr(orig_exc, "message", str(orig_exc))
                         match = self._ansible_error_re.match(
                             getattr(orig_exc, "message", str(orig_exc)),
@@ -184,17 +191,36 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                                 bypass = True
                             else:
                                 bypass = False
+                        elif isinstance(exc, ImportError):
+                            if self.options and self.options.nodeps:
+                                msg = f"Ignored exception {exc} due to running with nodeps mode."
+                                _logger.debug(msg)
+                                continue
+                            bypass = False
                         elif re.match(r"^lookup plugin (.*) not found$", exc.message):
                             # lookup plugin 'template' not found
                             bypass = True
+                        elif (
+                            exc.message == "A template was resolved to an Omit scalar."
+                            or (
+                                isinstance(orig_exc, AnsibleTemplateSyntaxError)
+                                and re.match(
+                                    r"^Syntax error in template: No filter named '.*'.",
+                                    exc.message,
+                                )
+                            )
+                        ):
+                            bypass = True
 
                         # AnsibleError: template error while templating string: expected token ':', got '}'. String: {{ {{ '1' }} }}
                         # AnsibleError: template error while templating string: unable to locate collection ansible.netcommon. String: Foo {{ buildset_registry.host | ipwrap }}
                         if not bypass:
+                            lineno = task.get_error_line([*path, key])
                             result.append(
                                 self.create_matcherror(
                                     message=str(exc),
-                                    lineno=task.get_error_line(path),
+                                    lineno=lineno,
+                                    data=v,
                                     filename=file,
                                     tag=f"{self.id}[invalid]",
                                 ),
@@ -206,6 +232,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                         lintable=file,
                     )
                     if reformatted != v:
+                        lineno = task.get_error_line([*path, key])
                         result.append(
                             self.create_matcherror(
                                 message=self._msg(
@@ -213,7 +240,8 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                                     value=v,
                                     reformatted=reformatted,
                                 ),
-                                lineno=task.get_error_line(path),
+                                lineno=lineno,
+                                data=v,
                                 details=details,
                                 filename=file,
                                 tag=f"{self.id}[{tag}]",
@@ -237,10 +265,10 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
 
         if str(file.kind) == "vars":
             data = parse_yaml_from_file(str(file.path))
-            if not isinstance(data, dict):
+            if not isinstance(data, Mapping):
                 return results
             for key, v, _path in nested_items_path(data):
-                if isinstance(v, AnsibleUnicode):
+                if isinstance(v, str):
                     reformatted, details, tag = self.check_whitespace(
                         v,
                         key=key,
@@ -254,7 +282,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                                     value=v,
                                     reformatted=reformatted,
                                 ),
-                                lineno=v.ansible_pos[1],
+                                data=v,
                                 details=details,
                                 filename=file,
                                 tag=f"{self.id}[{tag}]",
@@ -293,7 +321,9 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             )
         return tokens
 
-    def unlex(self, tokens: list[Token]) -> str:
+    def unlex(
+        self, tokens: list[Token], original_line_ending: str | None = None
+    ) -> str:
         """Return original text by compiling the lex output."""
         result = ""
         last_lineno = 1
@@ -304,6 +334,11 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             result += value
             last_lineno = lineno
             last_value = value
+
+        # Preserve original line endings if they were different from \n
+        if original_line_ending and original_line_ending != "\n":
+            result = result.replace("\n", original_line_ending)
+
         return result
 
     # pylint: disable=too-many-locals
@@ -336,6 +371,13 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                 return value
             return value[3:-3]
 
+        # Detect original line ending style to preserve it
+        # Only preserve \r\n (Windows CRLF), let \r (Mac classic) be normalized to \n
+        # as per jinja 3.0.0 behavior (see test case 44)
+        original_line_ending = None
+        if "\r\n" in text:
+            original_line_ending = "\r\n"
+
         tokens = []
         details = ""
         begin_types = ("variable_begin", "comment_begin", "block_begin")
@@ -415,7 +457,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
             return uncook(text, implicit=implicit), "", "spacing"
 
         # finalize
-        reformatted = self.unlex(tokens)
+        reformatted = self.unlex(tokens, original_line_ending)
         failed = reformatted != text
         reformatted = uncook(reformatted, implicit=implicit)
         details = (
@@ -506,31 +548,24 @@ if "pytest" in sys.modules:
     from ansiblelint.runner import Runner
     from ansiblelint.transformer import Transformer
 
-    @pytest.fixture(name="error_expected_lines")
-    def fixture_error_expected_lines() -> list[int]:
-        """Return list of expected error lines."""
-        return [33, 36, 39, 42, 45, 48, 74]
-
-    # 21 68
-    @pytest.fixture(name="lint_error_lines")
-    def fixture_lint_error_lines() -> list[int]:
-        """Get VarHasSpacesRules linting results on test_playbook."""
-        collection = RulesCollection()
-        collection.register(JinjaRule())
-        lintable = Lintable("examples/playbooks/jinja-spacing.yml")
-        results = Runner(lintable, rules=collection).run()
-        return [item.lineno for item in results]
-
-    def test_jinja_spacing_playbook(
-        error_expected_lines: list[int],
-        lint_error_lines: list[int],
-    ) -> None:
+    @pytest.mark.libyaml
+    def test_jinja_spacing_playbook() -> None:
         """Ensure that expected error lines are matching found linting error lines."""
         # list unexpected error lines or non-matching error lines
-        error_lines_difference = list(
-            set(error_expected_lines).symmetric_difference(set(lint_error_lines)),
-        )
-        assert len(error_lines_difference) == 0
+        lineno_list = [33, 36, 39, 42, 45, 48, 74]
+        lintable = Lintable("examples/playbooks/jinja-spacing.yml")
+        collection = RulesCollection()
+        collection.register(JinjaRule())
+        results = Runner(lintable, rules=collection).run()
+        assert len(results) == len(lineno_list)
+        for index, result in enumerate(results):
+            assert result.tag == "jinja[spacing]"
+            assert result.lineno == lineno_list[index]
+
+        # error_lines_difference = list(
+        #     set(error_expected_lines).symmetric_difference(set(lint_error_lines)),
+        # )
+        # assert len(error_lines_difference) == 0
 
     def test_jinja_spacing_vars() -> None:
         """Ensure that expected error details are matching found linting error details."""
@@ -762,6 +797,13 @@ if "pytest" in sys.modules:
                 "spacing",
                 id="45",
             ),
+            # Windows line endings (\r\n) should be preserved, but \r alone should normalize to \n
+            pytest.param(
+                "Created on {{ '%Y-%m-%d %H:%M:%S %Z' | strftime }}.\r\n",
+                "Created on {{ '%Y-%m-%d %H:%M:%S %Z' | strftime }}.\r\n",
+                "spacing",
+                id="46",
+            ),
         ),
     )
     def test_jinja(text: str, expected: str, tag: str) -> None:
@@ -833,10 +875,10 @@ if "pytest" in sys.modules:
         assert len(errs) == 2
         assert errs[0].tag == "jinja[spacing]"
         assert errs[0].rule.id == "jinja"
-        assert errs[0].lineno == 9
+        assert errs[0].lineno in [9, 13]  # ruamel w/ clib return different numbers
         assert errs[1].tag == "jinja[invalid]"
         assert errs[1].rule.id == "jinja"
-        assert errs[1].lineno == 9
+        assert errs[1].lineno in [9, 10, 13]  # 2.19 has better line identification
 
     def test_jinja_valid() -> None:
         """Tests our ability to parse jinja, even when variables may not be defined."""
@@ -885,10 +927,10 @@ if "pytest" in sys.modules:
             data = args[1]
 
             if data != "{{ 12 | random(seed=inventory_hostname) }}":
-                return do_template(*args, **kwargs)
+                return do_template(*args, **kwargs)  # type: ignore[no-untyped-call]
 
             msg = "Unexpected templating type error occurred on (foo): bar"
-            raise AnsibleError(msg)
+            raise AnsibleError(str(msg))  # type: ignore[no-untyped-call]
 
         do_template = Templar.do_template
         collection = RulesCollection()
@@ -897,3 +939,25 @@ if "pytest" in sys.modules:
         with mock.patch.object(Templar, "do_template", _do_template):
             results = Runner(lintable, rules=collection).run()
             assert len(results) == 0
+
+    @pytest.mark.parametrize(
+        ("nodeps", "expected_results"),
+        (
+            pytest.param(
+                "0",
+                0 if ansible_version() >= Version("2.19.0.dev0") else 1,
+                id="normal",
+            ),
+            pytest.param("1", 0, id="nodeps"),
+        ),
+    )
+    def test_filter_import_failure(
+        nodeps: str, expected_results: int, monkeypatch: pytest.MonkeyPatch
+    ) -> None:
+        """Tests how we process import failures from within filters."""
+        monkeypatch.setenv("ANSIBLE_LINT_NODEPS", nodeps)
+        collection = RulesCollection()
+        collection.register(JinjaRule())
+        lintable = Lintable("examples/playbooks/test_filter_with_importerror.yml")
+        results = Runner(lintable, rules=collection).run()
+        assert len(results) == expected_results
